% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/edf.R
\name{edf}
\alias{edf}
\title{Calculates EDF for set of random terms in asreml object}
\usage{
edf(asr.object)
}
\arguments{
\item{asr.object}{An asreml object from a fitted model}
}
\value{
A data frame with 2 columns: the term names and
    their calculated edf.
}
\description{
\code{edf} takes an asreml object and calculates EDF (effective degrees of freedom,
 cf Lee, Durban & Eilers, 2013) for all random terms in the fitted model.
}
\details{
Warnings: \itemize{
\item in the current version, this function only works when all terms have (scaled) identity variance models.
If there are non-identity variance models present, an error is generated.
\item the estimate may be inaccurate if convergence has not been achieved.
Eg. use \code{asreml.options(extra=10)} to force 10 extra iterations. If convergence has not
been achieved and the variance component is small, negative edf may occur.
}
}
\examples{
\dontrun{
data("wheatdata")
wheatdata$R <- as.factor(wheatdata$row)
wheatdata$C <- as.factor(wheatdata$col)

# Tensor-product spline using mbf in the asreml model
TPXZ <- tpsmmb("col", "row", wheatdata, stub="1", nsegments=c(14,21))
BcZ1.df <- TPXZ$BcZ.df
BrZ1.df <- TPXZ$BrZ.df
BcrZ1.df <- TPXZ$BcrZ.df
wh1.asr <- asreml(yield~1+TP.CR.2+TP.CR.3+TP.CR.4+colcode+rowcode+geno,
                 random=~R + C + TP.C.1:mbf(TP.row) + TP.C.2:mbf(TP.row) +
                         TP.R.1:mbf(TP.col) + TP.R.2:mbf(TP.col) +
                         mbf(TP.CxR),
                 mbf=TPXZ$mbflist,
                 data=TPXZ$data)
edf(wh1.asr)
tpsfit1 <- tpsfitted(wh1.asr, TPXZ)
tpsurface(tpsfit1)
}

}
