% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/tpsfitted.R
\name{tpsfitted}
\alias{tpsfitted}
\title{Get components of fitted tensor-product spline}
\usage{
tpsfitted(asr.object, tps.object)
}
\arguments{
\item{asr.object}{An \code{asreml} object. The \code{asreml} object used to fit the tensor-product spline.}

\item{tps.object}{An object from a call to \code{tpsmmb} used in the \code{asreml} fit}
}
\value{
A data frame with fitted values for each component of the  tensor product spline and their total.
Note: the fixed component of the model is centered to exclude the overall constant term.
}
\description{
\code{tpsfitted} gets components of fitted tensor product spline from an asreml object and
    the object generated by the \code{tpsmmb} function used to generate the spline design
    matrices
}
\details{
Assumes the the spline design
    matrices generated by the \code{tpsmmb} function are present in the model
    using the same names.
}
\examples{
\dontrun{
data("wheatdata")
wheatdata$R <- as.factor(wheatdata$row)
wheatdata$C <- as.factor(wheatdata$col)

# Tensor-product spline using mbf in the asreml model
TPXZ <- tpsmmb("col", "row", wheatdata, stub="1", nsegments=c(14,21))
BcZ1.df <- TPXZ$BcZ.df
BrZ1.df <- TPXZ$BrZ.df
BcrZ1.df <- TPXZ$BcrZ.df
wh1.asr <- asreml(yield~1+TP.CR.2+TP.CR.3+TP.CR.4+colcode+rowcode+geno,
                 random=~R + C + TP.C.1:mbf(TP.row) + TP.C.2:mbf(TP.row) +
                         TP.R.1:mbf(TP.col) + TP.R.2:mbf(TP.col) +
                         mbf(TP.CxR),
                 mbf=TPXZ$mbflist,
                 data=TPXZ$data)
edf(wh1.asr)
tpsfit1 <- tpsfitted(wh1.asr, TPXZ)
tpsurface(tpsfit1)

}

}
