% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/tpsurface.R
\name{tpsurface}
\alias{tpsurface}
\title{Contour or tile plot of surfaces}
\usage{
tpsurface(
  data,
  method = "contour",
  scale = "common",
  yaxis = "reverse",
  grid = "yes",
  nbreaks = 12,
  layout = NULL
)
}
\arguments{
\item{data}{A data frame. First two columns must be indexing vectors
named \code{"col"} and \code{"row"} giving the plot locations, remaining
columns are the surfaces to be plotted.}

\item{method}{A string. Whether to do a contour plot (interpolated)
\code{"contour"} or tile plot (actual values) \code{"tile"};
default \code{"contour"}.}

\item{scale}{A string. Whether to use a common scale across all plots
\code{"common"}, or separate scales \code{"separate"};
default \code{"common"}}

\item{yaxis}{A string. Whether to reverse y-axis so plots are in field
layout with (1,1) at top left \code{"reverse"} or leave in Cartesian
coordinates with (1,1) at bottom left \code{"original"}; default \code{"reverse"}.}

\item{grid}{A string. Whether to put all plots in grid on same page;
default \code{"yes"} or use separate pages \code{"no"}; default \code{"yes"}.
Note: a legend is provided only when scale=\code{"common"}.}

\item{nbreaks}{A numeric value. The target number of breaks to use in plotting
(=number of colours used); default 12.}

\item{layout}{A list with 2 values: number of columns & rows in the graphical layout.
Only relevant when \code{grid="yes"}. Default: determined automatically.}
}
\description{
\code{tpsurface} produces contour (or tile) plots of components of a fitted
    tensor-product spline, on common or separate scales
}
\examples{
\dontrun{
data("wheatdata")
wheatdata$R <- as.factor(wheatdata$row)
wheatdata$C <- as.factor(wheatdata$col)

# Tensor-product spline using mbf in the asreml model
TPXZ <- tpsmmb("col", "row", wheatdata, stub="1", nsegments=c(14,21))
BcZ1.df <- TPXZ$BcZ.df
BrZ1.df <- TPXZ$BrZ.df
BcrZ1.df <- TPXZ$BcrZ.df
wh1.asr <- asreml(yield~1+TP.CR.2+TP.CR.3+TP.CR.4+colcode+rowcode+geno,
                 random=~R + C + TP.C.1:mbf(TP.row) + TP.C.2:mbf(TP.row) +
                         TP.R.1:mbf(TP.col) + TP.R.2:mbf(TP.col) +
                         mbf(TP.CxR),
                 mbf=TPXZ$mbflist,
                 data=TPXZ$data)
edf(wh1.asr)
tpsfit1 <- tpsfitted(wh1.asr, TPXZ)
tpsurface(tpsfit1)
}

}
