test_that("tpsmmb generate design matrices as expected", {

  nc <- 15
  nr <- 22
  columns <- rep(c(1:nc), times=nr)
  rows <- rep(c(1:nr), each=nc)
  loc.df <- data.frame(col=columns, row=rows)

  # testing with asreml="mbf"
  bits <- tpsmmb("col", "row", data=loc.df, nseg=c(7,7), stub="x")
  expect_equal(length(bits), 7)
  expect_equal(length(bits$data), 13)
  expect_match(names(bits)[[2]], "mbflist")
  expect_equal_to_reference(bits$BcZ.df,file="BcZ.rds")
  expect_equal_to_reference(bits$BrZ.df,file="BrZ.rds")
  expect_equal_to_reference(bits$BcrZ.df,file="BcrZ.rds")
  mbflist <- list(TP.col=list(key=c("TP.col","TP.col"),cov="BcZx.df"),
                  TP.row=list(key=c("TP.row","TP.row"),cov="BrZx.df"),
                  TP.CxR=list(key=c("TP.CxR","TP.CxR"),cov="BcrZx.df"))
  expect_mapequal(bits$mbflist,mbflist)
  expect_equal(bits$mbflist, mbflist)
  cdim <- c("diff.c"=2,"nbc"=8,"nbcn"=8,
            "diff.r"=2,"nbr"=8,"nbrn"=8)
  expect_equal(bits$dim, cdim)
  tracelist <- list('Xc1:Zr'=46.6727526292, 'Xc2:Zr'=c(26.400748962),
                    'Zc:Xr1'=c(46.5289236111), 'Zc:Xr2'=c(25.2227498363),
                    'Zc:Zr'=c(27.2590712555))
  expect_mapequal(bits$trace,tracelist)

  # testing with asreml="mbf" & nesting
  bits <- tpsmmb("col","row",data=loc.df,nseg=c(14,21),nestorder=c(7,7),
                 stub="x")
  expect_equal_to_reference(bits$BcrZ.df,file="Bcrnest.rds")
  tracelist <- list('Xc1:Zr'=503.306078431, 'Xc2:Zr'=c(391.460283224),
                    'Zc:Xr1'=c(115.765114379), 'Zc:Xr2'=c(97.2426960783),
                    'Zc:Zr'=c(6.29526113983))
  expect_mapequal(bits$trace,tracelist)

  # testing with asreml="grp"
  bits <- tpsmmb("col","row",data=loc.df,nseg=c(14,21),nestorder=c(7,7),
                 asreml="grp", stub="x")
  expect_equal(length(bits), 8)
  expect_equal(length(bits$data), 99)
  expect_equal_to_reference(bits$data,file="gdata.rds")
  expect_equal(bits$mbflist, mbflist)
  cdim <- c("diff.c"=2,"nbc"=15,"nbcn"=3,
            "diff.r"=2,"nbr"=22,"nbrn"=4)
  expect_equal(bits$dim, cdim)
  grplist <- list(TP.C.1_frow=c(14:35), TP.C.2_frow=c(36:57),
                  TP.R.1_fcol=c(58:72), TP.R.2_fcol=c(73:87),
                  TP_fcol_frow=c(88:99), All=c(14:99))
  expect_mapequal(bits$grp,grplist)
  expect_equal(bits$grp, grplist)
  expect_mapequal(bits$trace,tracelist)

  # testing with asreml="sepgrp"
  bits <- tpsmmb("col","row",data=loc.df,nseg=c(14,21),nestorder=c(7,7),
                 asreml="sepgrp")
  expect_equal(length(bits), 8)
  expect_equal(length(bits$data), 66)
  expect_equal_to_reference(bits$data,file="sgdata.rds")
  expect_equal(bits$dim, cdim)
  sepgrplist <- list(TP_C=c(14:15), TP_R=c(16:17), TP_fcol=c(18:32),
                     TP_frow=c(33:54), TP_fcol_frow=c(55:66))
  expect_mapequal(bits$grp,sepgrplist)
  expect_equal(bits$grp, sepgrplist)
  expect_mapequal(bits$trace,tracelist)

  # testing with asreml="sepgrp" and eigenvalues="omit"
  ebits <- tpsmmb("col","row",data=loc.df,nseg=c(14,21),nestorder=c(7,7),
                 asreml="sepgrp", eigenvalues="omit")
  expect_equal(length(ebits), 9)
  expect_equal(length(ebits$data), 66)
  expect_equal(ebits$dim, cdim)
  expect_equal(ebits$grp, sepgrplist)
  expect_mapequal(ebits$trace,tracelist)
  expect_equal(length(ebits$eigen), 3)
  diagc <- c(15.70487804453830, 14.84680573079112, 13.50419780902914,
             11.79669371385492,  9.87025861228383,  7.87942214639867,
             5.96918489442442,  4.25913186075079,  2.83191978955755,
             1.72760712076277,  0.94437806119036,  0.44521558903629,
             0.16916848036960,  0.04512383840546,  0.00601430860681)
  diagr <- c(15.85502694130977, 15.42669686184726, 14.73436685925584,
             13.80896042026247, 12.69105915872558, 11.42842226311316,
             10.07310775334389,  8.67839662981351,  7.29573325288100,
             5.97189193180400,  4.74656098737019,  3.65050286854691,
             2.70440466355900,  1.91848081975422,  1.29283297700221,
             0.81851480487638,  0.47919699706634, 0.25328335262719,
             0.11629676931890,  0.04333860591961,  0.01141364016728,
             0.00151144143531)
  diagcr <- c(25.56407315293, 19.78445962126, 14.79374353867, 12.57335707034,
              18.38516480713, 12.60555127546,  7.61483519287, 5.39444872454,
              14.20625646133,  8.42664292966,  3.43592684707,  1.21554037874)
  expect_equal(ebits$eigen$diagc, diagc)
  expect_equal(ebits$eigen$diagr, diagr)
  expect_equal(ebits$eigen$diagcr, diagcr)
  Zr <- as.matrix(bits$data[sepgrplist$TP_frow])
  Zc <- as.matrix(bits$data[sepgrplist$TP_fcol])
  Zcr <- as.matrix(bits$data[sepgrplist$TP_fcol_frow])
  uZr <- as.matrix(ebits$data[sepgrplist$TP_frow])
  scZr <- uZr%*%diag(1/sqrt(diagr))
  uZc <- as.matrix(ebits$data[sepgrplist$TP_fcol])
  scZc <- uZc%*%diag(1/sqrt(diagc))
  uZcr <- as.matrix(ebits$data[sepgrplist$TP_fcol_frow])
  scZcr <- uZcr%*%diag(1/sqrt(diagcr))
  expect_equivalent(Zr, scZr)
  expect_equivalent(Zc, scZc)
  expect_equivalent(Zcr, scZcr)

})
